@@ -9,6 +9,7 @@
 #define KCAPACITYBAR_H
 
 #include <QWidget>
+#include <memory>
 
 #include <kwidgetsaddons_export.h>
 
@@ -30,8 +31,7 @@ class QPaintEvent;
  *
  * @author Rafael Fernández López <ereslibre@kde.org>
  */
-class KWIDGETSADDONS_EXPORT KCapacityBar
-    : public QWidget
+class KWIDGETSADDONS_EXPORT KCapacityBar : public QWidget
 {
     Q_OBJECT
 
@@ -41,17 +41,15 @@ class KWIDGETSADDONS_EXPORT KCapacityBar
     Q_PROPERTY(bool fillFullBlocks READ fillFullBlocks WRITE setFillFullBlocks)
     Q_PROPERTY(bool continuous READ continuous WRITE setContinuous)
     Q_PROPERTY(int barHeight READ barHeight WRITE setBarHeight)
-    Q_PROPERTY(Qt::Alignment horizontalTextAlignment READ horizontalTextAlignment
-               WRITE setHorizontalTextAlignment)
+    Q_PROPERTY(Qt::Alignment horizontalTextAlignment READ horizontalTextAlignment WRITE setHorizontalTextAlignment)
 
 public:
     enum DrawTextMode {
-        DrawTextInline = 0,     ///< If any text set, draw it into the capacity bar
-        DrawTextOutline         ///< If any text set, draw it out of the capacity bar
+        DrawTextInline = 0, ///< If any text set, draw it into the capacity bar
+        DrawTextOutline, ///< If any text set, draw it out of the capacity bar
     };
     Q_ENUM(DrawTextMode)
 
-
     /**
      * Constructs a capacity bar with DrawTextOutline as draw text mode.
      * @param parent The parent of the widget.
@@ -218,8 +216,7 @@ private:
     /**
      * @internal
      */
-    class Private;
-    Private *const d;
+    std::unique_ptr<class KCapacityBarPrivate> const d;
 };
 
 #endif
